import json
import sys
import spectra
import numpy as np
import plotly.graph_objects as go
from plotly.subplots import make_subplots

f = open("cmdtest.json")
prm = json.load(f)
prmstr = json.dumps(prm)

solver = spectra.Solver(prmstr)
isready = solver.IsReady()
if isready == False:
	print("Parameter load failed.")
	sys.exit()

solver.Run()

# retrieve Modal Profile
captions = solver.GetCMDCaptions("Modal Profile")
titles = captions["titles"]
units = captions["units"]

data = solver.GetCMDData("Modal Profile")
xyarray = data["variables"]
nx = len(xyarray[0])
ny = len(xyarray[1])
nmode = len(xyarray[2])
amplitude = np.array(data["data"][0]).reshape([nmode, ny, nx])

titleunits = []
for i in range(len(titles)):
	titleunits.append(titles[i]+" ("+units[i]+")")

spec3d = {"is_3d": True}
modes = [0,1,2,3,4,5,6,9,10]
specs = [spec3d, spec3d, spec3d]
titles = []
for i in range(len(modes)):
	titles.append(str(modes[i])+"-th Mode")

fig = make_subplots(rows = 3, cols = 3,
                    specs = [specs, specs, specs],
					horizontal_spacing = 0.05,
					vertical_spacing  = 0.05,
                    subplot_titles = titles,
                    )
for i in range(len(modes)):
	col, row = divmod(i, 3)
	fig.add_trace(go.Surface(x = xyarray[0], y = xyarray[1], z = amplitude[modes[i]], showscale=False), row = row+1, col = col+1)

scenevar = dict(
	xaxis_title = titleunits[0],
	yaxis_title = titleunits[1],
	zaxis_title = titleunits[3])

fig.update_layout(
	title = "CMD Examle: Modal Profile",
	scene = scenevar,
	scene2 = scenevar,
	scene3 = scenevar,
	scene4 = scenevar,
	scene5 = scenevar,
	scene6 = scenevar,
	scene7 = scenevar,
	scene8 = scenevar,
	margin=dict(r=20, b=10, l=10, t=50))
fig.show()

# retrieve Wigner function
captions = solver.GetCMDCaptions("Wigner Func. (Y,Y')")
titles = captions["titles"]
units = captions["units"]

data = solver.GetCMDData("Wigner Func. (Y,Y')")
xyarray = data["variables"]
nx = len(xyarray[0])
ny = len(xyarray[1])
zorg = np.array(data["data"][0]).reshape([ny, nx])
zrec = np.array(data["data"][1]).reshape([ny, nx])

titleunits = []
for i in range(len(titles)):
	titleunits.append(titles[i]+" ("+units[i]+")")

fig = make_subplots(rows=1, cols=2,
                    specs=[[spec3d, spec3d]],
					horizontal_spacing = 0.05,
                    subplot_titles=["Original", "Reconstructed"],
                    )
fig.add_trace(go.Surface(x = xyarray[0], y = xyarray[1], z = zorg, showscale=False), 1, 1)
fig.add_trace(go.Surface(x = xyarray[0], y = xyarray[1], z = zrec, showscale=False), 1, 2)
scenevar = dict(
	xaxis_title = titleunits[0],
	yaxis_title = titleunits[1],
	zaxis_title = titleunits[2])
fig.update_layout(
	title = "CMD Examle: Comparison of Wigner Function",
	scene = scenevar, scene2 = scenevar,
	margin = dict(r=20, b=10, l=10, t=50))
fig.show()


# retrieve modal flux
captions = solver.GetCMDCaptions("Modal Flux")
titles = captions["titles"]
units = captions["units"]

data = solver.GetCMDData("Modal Flux")
mode = data["variables"][0]
modalflux = data["data"][0]

titleunits = []
for i in range(len(titles)):
	titleunits.append(titles[i]+" ("+units[i]+")")

fig = go.Figure()
fig.add_trace(go.Scatter(x = mode, y = modalflux))
fig.update_xaxes(title = titleunits[0])
fig.update_yaxes(title = titleunits[1])
fig.update_layout(title="CMD Examle: Modal Flux")
fig.show()
