import json
import sys
import spectra
import plotly.graph_objects as go

# open an input file
f = open("sample.json")
prm = json.load(f)
prmstr = json.dumps(prm)

# call solver with the input string (JSON format)
solver = spectra.Solver(prmstr)

# check if the paramete load is OK
isready = solver.IsReady()
if isready == False:
	print("Parameter load failed.")
	sys.exit()

# start calculation
solver.Run()

# get results
# get titles and units
captions = solver.GetCaptions()
titles = captions["titles"]
units = captions["units"]

# get the output data
data = solver.GetData()
energy = data["variables"][0]
flux = data["data"][0]

titleunits = []
for i in range(len(titles)):
	titleunits.append(titles[i]+' ('+units[i]+')')

fig = go.Figure()
fig.add_trace(go.Scatter(x=energy, y=flux))
fig.update_xaxes(title=titleunits[0])
fig.update_yaxes(title=titleunits[1])
fig.update_layout(title="Example of Calling SPECTRA from Python Script")

fig.show()
