import json
import sys
import spectra
import numpy as np
import plotly.graph_objects as go

f = open("sample2.json")
prm = json.load(f)
prmstr = json.dumps(prm)

solver = spectra.Solver(prmstr)
isready = solver.IsReady()
if isready == False:
	print("Parameter load failed.")
	sys.exit()

solver.Run()
captions = solver.GetCaptions()
titles = captions["titles"]
units = captions["units"]
data = solver.GetData()
xyarray = data["variables"]
flux = data["data"]

nx = len(xyarray[0])
ny = len(xyarray[1])
zdata = np.array(flux[0]).reshape([ny, nx])

titleunits = []
for i in range(len(titles)):
	titleunits.append(titles[i]+' ('+units[i]+')')

fig = go.Figure()
fig.add_trace(go.Surface(x = xyarray[0], y = xyarray[1], z = zdata))
fig.update_layout(scene = dict(
	xaxis_title = titleunits[0],
	yaxis_title = titleunits[1],
	zaxis_title = titleunits[2]),
	width = 700,
	margin=dict(r=20, b=10, l=10, t=10))
fig.update_layout(title="Example 2: Arrangement of 2D Data")

fig.show()
