import json
import sys
import spectra
import plotly.graph_objects as go

f = open("sample.json")
prm = json.load(f)
prmstr = json.dumps(prm)

solver = spectra.Solver(prmstr)
isready = solver.IsReady()
if isready == False:
	print("Parameter load failed.")
	sys.exit()

# change the energy range
prm["Configurations"]["Energy Range (eV)"] = [10000,15000]

# retrieve the default beta_y
betay = prm["Accelerator"]["&beta;<sub>x,y</sub> (m)"][1]

# arrange scan values (beta_x)
values = [[1,betay],[10,betay],[30,betay],[100,betay]]

results = []
process = 1
for betaxy in values:
	# change beta_x,y vector
	prm["Accelerator"]["&beta;<sub>x,y</sub> (m)"] = betaxy
	prmstr = json.dumps(prm)
	if solver.Set(prmstr) == False:
		print("Parameter load failed.")
		sys.exit()

	solver.Run()
	data = solver.GetData()
	results.append([data["data"][0], betaxy])
	print("\nProcess ", process, " Finished.")
	process += 1

captions = solver.GetCaptions()
titles = captions["titles"]
units = captions["units"]
energy = data["variables"][0]

titleunits = []
for i in range(len(titles)):
	titleunits.append(titles[i]+" ("+units[i]+")")

fig = go.Figure()

for result in results:
	fig.add_trace(go.Scatter(x=energy, y=result[0], name=result[1][0]))

fig.update_xaxes(title=titleunits[0])
fig.update_yaxes(title=titleunits[1])
fig.update_layout(legend_title_text="horizontal beta (m)")
fig.show()
